@@ -58,7 +58,7 @@ extern GameMode_t gamemode;
 extern GameMission_t  gamemission;
 extern const char *doomverstr;
 
-extern char *MAPNAME(int e, int m);
+extern char *VANILLA_MAP_LUMP_NAME(int e, int m);
 
 // Set if homebrew PWAD stuff has been added.
 extern  dboolean modifiedgame;
@@ -139,13 +139,13 @@ extern  Language_t   language;
 //
 
 // Defaults for menu, methinks.
-extern  skill_t   startskill;
+extern  int   startskill;
 extern  int             startepisode;
 
 extern  dboolean   autostart;
 
 // Selected by user.
-extern  skill_t         gameskill;
+extern  int   gameskill;
 extern  int   gameepisode;
 extern  int   gamemap;
 
@@ -162,9 +162,6 @@ extern leave_data_t leave_data;
 #define LF_SET_ANGLE 0x01
 #define LEAVE_VICTORY -1
 
-// Nightmare mode flag, single player.
-extern  dboolean         respawnmonsters;
-
 // Netgame? Only true if >1 player.
 extern  dboolean netgame;
 
@@ -227,7 +224,8 @@ extern  int totalkills, totallive;
 extern  int totalitems;
 extern  int totalsecret;
 
-extern  int basetic;
+extern  int boom_basetic;
+extern  int true_basetic;
 extern  int leveltime;       // level time in tics
 extern  int totalleveltimes; // sum of intermission times in tics at second resolution
 extern  int levels_completed;
@@ -239,6 +237,9 @@ extern  dboolean demoplayback;
 extern  dboolean demorecording;
 extern  int demover;
 
+#define allow_incompatibility (!demorecording && !demoplayback)
+#define comperr(i) (default_comperr[i] && allow_incompatibility)
+
 extern  dboolean userdemo;
 #define userplayback (demoplayback && userdemo)
 #define reelplayback (demoplayback && !userdemo)
@@ -259,7 +260,8 @@ extern  dboolean     in_game;
 
 extern  int   gametic;
 
-#define logictic (gametic - basetic)
+#define boom_logictic (gametic - boom_basetic)
+#define true_logictic (gametic - true_basetic)
 
 //e6y
 extern  dboolean realframe;
