@@ -428,6 +428,8 @@ void dsda_WatchAfterLevelSetup(void) {
   dsda_ResetTrackers();
   dsda_ResetLineActivationTracker();
   dsda_WadStatsEnterMap();
+  player_damage_last_tic = 0;
+  player_damage_leveltime = 0;
 }
 
 void dsda_WatchNewLevel(void) {
@@ -518,7 +520,7 @@ static void dsda_ResetTracking(void) {
   dsda_pacifist_note_shown = false;
 }
 
-void dsda_WatchDeferredInitNew(skill_t skill, int episode, int map) {
+void dsda_WatchDeferredInitNew(int skill, int episode, int map) {
   if (!demorecording) return;
 
   ++dsda_session_attempts;
@@ -535,7 +537,8 @@ void dsda_WatchDeferredInitNew(skill_t skill, int episode, int map) {
 
   dsda_InitDemoRecording();
 
-  basetic = gametic;
+  boom_basetic = gametic;
+  true_basetic = gametic;
 }
 
 void dsda_WatchNewGame(void) {
