@@ -73,7 +73,7 @@ void dsda_WatchNewLevel(void);
 void dsda_WatchLevelCompletion(void);
 void dsda_WatchWeaponFire(weapontype_t weapon);
 void dsda_WatchSecret(void);
-void dsda_WatchDeferredInitNew(skill_t skill, int episode, int map);
+void dsda_WatchDeferredInitNew(int skill, int episode, int map);
 void dsda_WatchNewGame(void);
 void dsda_WatchLevelReload(int* reloaded);
 void dsda_WatchLineActivation(line_t* line, mobj_t* mo);
