@@ -90,7 +90,7 @@ static arg_config_t arg_config[dsda_arg_count] = {
   },
   [dsda_arg_record] = {
     "-record", NULL, NULL,
-    "records a demo to the give file",
+    "records a demo to the given file",
     arg_string,
   },
   [dsda_arg_recordfromto] = {
@@ -111,7 +111,17 @@ static arg_config_t arg_config[dsda_arg_count] = {
   [dsda_arg_skill] = {
     "-skill", NULL, NULL,
     "sets the skill level",
-    arg_int, 1, 5,
+    arg_int, 1, 255,
+  },
+  [dsda_arg_uv] = {
+    "-uv", NULL, NULL,
+    "sets the skill level to 4",
+    arg_null,
+  },
+  [dsda_arg_nm] = {
+    "-nm", NULL, NULL,
+    "sets the skill level to 5",
+    arg_null,
   },
   [dsda_arg_episode] = {
     "-episode", NULL, NULL,
@@ -168,11 +178,6 @@ static arg_config_t arg_config[dsda_arg_count] = {
     "sets a random player class in hexen deathmatch",
     arg_null,
   },
-  [dsda_arg_baddemo] = {
-    "-baddemo", NULL, NULL,
-    "allows recording in experimental map formats",
-    arg_null,
-  },
   [dsda_arg_dsdademo] = {
     "-dsdademo", NULL, NULL,
     "turns on extended demo format (for testing)",
@@ -328,6 +333,11 @@ static arg_config_t arg_config[dsda_arg_count] = {
     "export a dsda-format text file template",
     arg_null,
   },
+  [dsda_arg_track_playback] = {
+    "-track_playback", NULL, NULL,
+    "treat demo playback as an attempt for the given split file base",
+    arg_string,
+  },
   [dsda_arg_export_ghost] = {
     "-export_ghost", NULL, NULL,
     "exports a ghost file",
@@ -353,11 +363,6 @@ static arg_config_t arg_config[dsda_arg_count] = {
     "sets a magic block of memory for certain overrun demos",
     arg_string_array, 0, 0, 1, 10,
   },
-  [dsda_arg_mapinfo] = {
-    "-mapinfo", NULL, NULL,
-    "turn on (partial) MAPINFO support",
-    arg_null,
-  },
   [dsda_arg_data] = {
     "-data", NULL, NULL,
     "sets the data directory",
@@ -423,6 +428,11 @@ static arg_config_t arg_config[dsda_arg_count] = {
     "force classic bsp nodes",
     arg_null,
   },
+  [dsda_arg_force_old_zdoom_nodes] = {
+    "-force_old_zdoom_nodes", NULL, NULL,
+    "force extended (non-gl) zdoom nodes",
+    arg_null,
+  },
   [dsda_arg_sigsegv] = {
     "-sigsegv", NULL, NULL,
     "disable the SIGSEGV signal handler",
@@ -475,7 +485,7 @@ static arg_config_t arg_config[dsda_arg_count] = {
   },
   [dsda_arg_nomapinfo] = {
     "-nomapinfo", NULL, NULL,
-    "skip UMAPINFO lumps",
+    "skip *MAPINFO lumps",
     arg_null,
   },
   [dsda_arg_noautoload] = {
@@ -673,6 +683,11 @@ static arg_config_t arg_config[dsda_arg_count] = {
     "sets a special flag to compensate for sync errors in certain demos",
     arg_null,
   },
+  [dsda_arg_debug_mapinfo] = {
+    "-debug_mapinfo", NULL, NULL,
+    "turns on mapinfo parsing in doom (temporary arg for testing)",
+    arg_null,
+  },
 };
 
 static dsda_arg_t arg_value[dsda_arg_count];
@@ -833,6 +848,12 @@ void dsda_ParseCommandLineArgs(int argc, char** argv) {
         I_Error("Unknown command line option %s\n", dsda_argv[argv_i]);
     }
   }
+
+  if (dsda_Flag(dsda_arg_uv))
+    dsda_UpdateIntArg(dsda_arg_skill, "4");
+
+  if (dsda_Flag(dsda_arg_nm))
+    dsda_UpdateIntArg(dsda_arg_skill, "5");
 }
 
 void dsda_UpdateIntArg(dsda_arg_identifier_t id, const char* param) {
