@@ -33,6 +33,8 @@ typedef enum {
   dsda_arg_from_key_frame,
   dsda_arg_warp,
   dsda_arg_skill,
+  dsda_arg_uv,
+  dsda_arg_nm,
   dsda_arg_episode,
   dsda_arg_complevel,
   dsda_arg_fast,
@@ -44,7 +46,6 @@ typedef enum {
   dsda_arg_hexen,
   dsda_arg_class,
   dsda_arg_randclass,
-  dsda_arg_baddemo,
   dsda_arg_dsdademo,
   dsda_arg_solo_net,
   dsda_arg_coop_spawns,
@@ -76,12 +77,12 @@ typedef enum {
   dsda_arg_analysis,
   dsda_arg_levelstat,
   dsda_arg_export_text_file,
+  dsda_arg_track_playback,
   dsda_arg_export_ghost,
   dsda_arg_import_ghost,
   dsda_arg_consoleplayer,
   dsda_arg_spechit,
   dsda_arg_setmem,
-  dsda_arg_mapinfo,
   dsda_arg_data,
   dsda_arg_save,
   dsda_arg_config,
@@ -95,6 +96,7 @@ typedef enum {
   dsda_arg_v,
   dsda_arg_resetgamma,
   dsda_arg_forceoldbsp,
+  dsda_arg_force_old_zdoom_nodes,
   dsda_arg_sigsegv,
   dsda_arg_deathmatch,
   dsda_arg_altdeath,
@@ -145,6 +147,7 @@ typedef enum {
   dsda_arg_do_not_use_misc12_frame_parameters_in_a_mushroom,
   dsda_arg_apply_mbf_codepointers_to_any_complevel,
   dsda_arg_reset_monsterspawner_params_after_loading,
+  dsda_arg_debug_mapinfo,
   dsda_arg_count,
 } dsda_arg_identifier_t;
 
