@@ -25,6 +25,7 @@
 #include "gl_struct.h"
 #include "lprintf.h"
 #include "r_main.h"
+#include "r_segs.h"
 #include "s_sound.h"
 #include "smooth.h"
 #include "v_video.h"
@@ -86,7 +87,6 @@ extern int sts_always_red;
 extern int sts_pct_always_gray;
 extern int sts_traditional_keys;
 extern int full_sounds;
-extern int fake_contrast;
 
 void I_Init2(void);
 void M_ChangeDemoSmoothTurns(void);
@@ -129,20 +129,7 @@ void deh_changeCompTranslucency(void);
 void dsda_InitGameControllerParameters(void);
 void dsda_InitExHud(void);
 void dsda_UpdateFreeText(void);
-
-// TODO: migrate all kinds of stuff from M_Init
-
-// TODO: automatically go through strict list
-void dsda_UpdateStrictMode(void) {
-  I_Init2(); // side effect of realtic clock rate
-  M_ChangeSpeed(); // side effect of always sr50
-  dsda_InitKeyFrame();
-  M_ChangeSkyMode(); // affected by mouselook setting
-  HU_InitCrosshair();
-  M_ChangeApplyPalette();
-  dsda_RefreshExHudCoordinateDisplay();
-  dsda_RefreshExHudCommandDisplay();
-}
+void dsda_ResetAirControl(void);
 
 void dsda_TrackConfigFeatures(void) {
   if (!demorecording)
@@ -204,6 +191,26 @@ void dsda_TrackConfigFeatures(void) {
 
   if (dsda_IntConfig(dsda_config_show_alive_monsters))
     dsda_TrackFeature(uf_showalive);
+
+  if (dsda_IntConfig(dsda_config_map_textured) || dsda_IntConfig(dsda_config_show_minimap))
+    dsda_TrackFeature(uf_advanced_map);
+}
+
+// TODO: migrate all kinds of stuff from M_Init
+
+// TODO: automatically go through strict list
+void dsda_UpdateStrictMode(void) {
+  I_Init2(); // side effect of realtic clock rate
+  M_ChangeSpeed(); // side effect of always sr50
+  dsda_InitKeyFrame();
+  M_ChangeSkyMode(); // affected by mouselook setting
+  HU_InitCrosshair();
+  M_ChangeApplyPalette();
+  M_ChangeMapTextured();
+  dsda_RefreshExHudCoordinateDisplay();
+  dsda_RefreshExHudCommandDisplay();
+  dsda_RefreshExHudMinimap();
+  dsda_TrackConfigFeatures();
 }
 
 dsda_config_t dsda_config[dsda_config_count] = {
@@ -339,7 +346,7 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_show_minimap] = {
     "dsda_show_minimap", dsda_config_show_minimap,
-    CONF_BOOL(0), NULL, NOT_STRICT, dsda_RefreshExHudMinimap
+    CONF_BOOL(0), NULL, STRICT_INT(0), dsda_RefreshExHudMinimap
   },
   [dsda_config_show_level_splits] = {
     "dsda_show_level_splits", dsda_config_show_level_splits,
@@ -666,10 +673,6 @@ dsda_config_t dsda_config[dsda_config_count] = {
     "startup_delay_ms", dsda_config_startup_delay_ms,
     dsda_config_int, 0, 1000, { 0 }
   },
-  [dsda_config_snd_pcspeaker] = {
-    "snd_pcspeaker", dsda_config_snd_pcspeaker,
-    CONF_BOOL(0), NULL, NOT_STRICT, I_InitSoundParams
-  },
   [dsda_config_pitched_sounds] = {
     "pitched_sounds", dsda_config_pitched_sounds,
     CONF_BOOL(0), NULL, NOT_STRICT, I_InitSoundParams
@@ -726,10 +729,38 @@ dsda_config_t dsda_config[dsda_config_count] = {
     "mus_fluidsynth_gain", dsda_config_mus_fluidsynth_gain,
     dsda_config_int, 0, 1000, { 50 }
   },
+  [dsda_config_mus_fluidsynth_chorus_depth] = {
+    "mus_fluidsynth_chorus_depth", dsda_config_mus_fluidsynth_chorus_depth,
+    dsda_config_int, 0, 10000, { 500 }
+  },
+  [dsda_config_mus_fluidsynth_chorus_level] = {
+    "mus_fluidsynth_chorus_level", dsda_config_mus_fluidsynth_chorus_level,
+    dsda_config_int, 0, 1000, { 35 }
+  },
+  [dsda_config_mus_fluidsynth_reverb_damp] = {
+    "mus_fluidsynth_reverb_damp", dsda_config_mus_fluidsynth_reverb_damp,
+    dsda_config_int, 0, 1000, { 40 }
+  },
+  [dsda_config_mus_fluidsynth_reverb_level] = {
+    "mus_fluidsynth_reverb_level", dsda_config_mus_fluidsynth_reverb_level,
+    dsda_config_int, 0, 1000, { 15 }
+  },
+  [dsda_config_mus_fluidsynth_reverb_width] = {
+    "mus_fluidsynth_reverb_width", dsda_config_mus_fluidsynth_reverb_width,
+    dsda_config_int, 0, 10000, { 400 }
+  },
+  [dsda_config_mus_fluidsynth_reverb_room_size] = {
+    "mus_fluidsynth_reverb_room_size", dsda_config_mus_fluidsynth_reverb_room_size,
+    dsda_config_int, 0, 1000, { 60 }
+  },
   [dsda_config_mus_opl_gain] = {
     "mus_opl_gain", dsda_config_mus_opl_gain,
     dsda_config_int, 0, 1000, { 50 }
   },
+  [dsda_config_mus_opl_opl3mode] = {
+    "mus_opl_opl3mode", dsda_config_mus_opl_opl3mode,
+    CONF_BOOL(1)
+  },
   [dsda_config_mus_portmidi_reset_type] = {
     "mus_portmidi_reset_type", dsda_config_mus_portmidi_reset_type,
     CONF_STRING("gm") // none, gs, gm, gm2, xg
@@ -916,7 +947,7 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_allow_jumping] = {
     "dsda_allow_jumping", dsda_config_allow_jumping,
-    CONF_BOOL(0)
+    CONF_BOOL(0), NULL, NOT_STRICT, dsda_ResetAirControl
   },
   [dsda_config_parallel_sfx_limit] = {
     "dsda_parallel_sfx_limit", dsda_config_parallel_sfx_limit,
@@ -1004,7 +1035,7 @@ dsda_config_t dsda_config[dsda_config_count] = {
   },
   [dsda_config_map_textured] = {
     "map_textured", dsda_config_map_textured,
-    CONF_BOOL(1), NULL, NOT_STRICT, M_ChangeMapTextured
+    CONF_BOOL(1), NULL, STRICT_INT(0), M_ChangeMapTextured
   },
   [dsda_config_map_textured_trans] = {
     "map_textured_trans", dsda_config_map_textured_trans,
@@ -1055,6 +1086,10 @@ dsda_config_t dsda_config[dsda_config_count] = {
     "dsda_fps_limit", dsda_config_fps_limit,
     dsda_config_int, 0, 1000, { 0 }
   },
+  [dsda_config_background_fps_limit] = {
+    "dsda_background_fps_limit", dsda_config_background_fps_limit,
+    dsda_config_int, 0, 1000, { 35 }
+  },
   [dsda_config_usegamma] = {
     "usegamma", dsda_config_usegamma,
     dsda_config_int, 0, 4, { 0 }, &usegamma, NOT_STRICT, M_ChangeApplyPalette
@@ -1099,9 +1134,10 @@ dsda_config_t dsda_config[dsda_config_count] = {
     "render_doom_lightmaps", dsda_config_render_doom_lightmaps,
     CONF_BOOL(0)
   },
-  [dsda_config_fake_contrast] = {
-    "fake_contrast", dsda_config_fake_contrast,
-    CONF_BOOL(1), &fake_contrast
+  [dsda_config_fake_contrast_mode] = {
+    "fake_contrast_mode", dsda_config_fake_contrast_mode,
+    dsda_config_int, FAKE_CONTRAST_MODE_OFF, FAKE_CONTRAST_MODE_SMOOTH,
+    { FAKE_CONTRAST_MODE_ON }, (int*) &fake_contrast_mode
   },
   [dsda_config_render_stretch_hud] = {
     "render_stretch_hud", dsda_config_render_stretch_hud,
@@ -1120,6 +1156,10 @@ dsda_config_t dsda_config[dsda_config_count] = {
     "render_stretchsky", dsda_config_render_stretchsky,
     CONF_BOOL(1)
   },
+  [dsda_config_gl_fade_mode] = {
+    "gl_fade_mode", dsda_config_gl_fade_mode,
+    dsda_config_int, 0, 1, { 0 }
+  },
   [dsda_config_boom_translucent_sprites] = {
     "boom_translucent_sprites", dsda_config_boom_translucent_sprites,
     CONF_BOOL(1), NULL, NOT_STRICT, deh_changeCompTranslucency
