@@ -120,6 +120,7 @@ typedef enum {
   dsda_config_gl_render_fov,
   dsda_config_gl_health_bar,
   dsda_config_gl_usevbo,
+  dsda_config_gl_fade_mode,
   dsda_config_use_mouse,
   dsda_config_mouse_sensitivity_horiz,
   dsda_config_mouse_sensitivity_vert,
@@ -138,7 +139,6 @@ typedef enum {
   dsda_config_movement_shorttics,
   dsda_config_screenshot_dir,
   dsda_config_startup_delay_ms,
-  dsda_config_snd_pcspeaker,
   dsda_config_pitched_sounds,
   dsda_config_full_sounds,
   dsda_config_snd_samplerate,
@@ -153,7 +153,14 @@ typedef enum {
   dsda_config_mus_fluidsynth_chorus,
   dsda_config_mus_fluidsynth_reverb,
   dsda_config_mus_fluidsynth_gain,
+  dsda_config_mus_fluidsynth_chorus_depth,
+  dsda_config_mus_fluidsynth_chorus_level,
+  dsda_config_mus_fluidsynth_reverb_damp,
+  dsda_config_mus_fluidsynth_reverb_level,
+  dsda_config_mus_fluidsynth_reverb_width,
+  dsda_config_mus_fluidsynth_reverb_room_size,
   dsda_config_mus_opl_gain,
+  dsda_config_mus_opl_opl3mode,
   dsda_config_mus_portmidi_reset_type,
   dsda_config_mus_portmidi_reset_delay,
   dsda_config_mus_portmidi_filter_sysex,
@@ -235,6 +242,7 @@ typedef enum {
   dsda_config_render_vsync,
   dsda_config_uncapped_framerate,
   dsda_config_fps_limit,
+  dsda_config_background_fps_limit,
   dsda_config_usegamma,
   dsda_config_screenblocks,
   dsda_config_sdl_video_window_pos,
@@ -246,7 +254,7 @@ typedef enum {
   dsda_config_integer_scaling,
   dsda_config_render_aspect,
   dsda_config_render_doom_lightmaps,
-  dsda_config_fake_contrast,
+  dsda_config_fake_contrast_mode,
   dsda_config_render_stretch_hud,
   dsda_config_render_patches_scalex,
   dsda_config_render_patches_scaley,
