@@ -37,6 +37,7 @@
 #include "dsda/features.h"
 #include "dsda/key_frame.h"
 #include "dsda/map_format.h"
+#include "dsda/preferences.h"
 #include "dsda/settings.h"
 #include "dsda/split_tracker.h"
 #include "dsda/utility.h"
@@ -54,15 +55,17 @@ static int largest_real_offset;
 static int demo_tics;
 static int compatibility_level_unspecified;
 
-#define DSDA_DEMO_VERSION 2
+#define DSDA_UDMF_VERSION 1
+#define DSDA_DEMO_VERSION 3
 #define DSDA_DEMO_HEADER_START_SIZE 8 // version + signature (6) + dsda version
 
-const int dsda_demo_header_data_size[DSDA_DEMO_VERSION + 1] = { 0, 8, 9 };
+const int dsda_demo_header_data_size[DSDA_DEMO_VERSION + 1] = { 0, 8, 9, 10 };
 
 typedef struct {
   int end_marker_location;
   int demo_tics;
   byte flags;
+  byte udmf_version;
 } dsda_demo_header_data_t;
 
 static dsda_demo_header_data_t dsda_demo_header_data;
@@ -78,6 +81,10 @@ static int bytes_per_tic;
 
 static dboolean use_demo_name_with_time;
 
+int dsda_DemoTic(void) {
+  return demo_tics;
+}
+
 const char* dsda_DemoNameBase(void) {
   return dsda_demo_name_base;
 }
@@ -208,9 +215,9 @@ static void dsda_EnsureDemoBufferSpace(size_t length) {
   );
 }
 
-dboolean dsda_CopyPendingCmd(ticcmd_t* cmd) {
-  if (demorecording && largest_real_offset - dsda_DemoBufferOffset() >= bytes_per_tic) {
-    const byte* p = dsda_demo_write_buffer_p;
+dboolean dsda_CopyPendingCmd(ticcmd_t* cmd, int delta) {
+  if (demorecording && largest_real_offset - dsda_DemoBufferOffset() >= (delta + 1) * bytes_per_tic) {
+    const byte* p = dsda_demo_write_buffer_p + delta * bytes_per_tic;
 
     G_ReadOneTick(cmd, &p);
 
@@ -240,11 +247,11 @@ void dsda_RestoreCommandHistory(void) {
   ticcmd_t cmd = { 0 };
 
   // the dsda format has variable bytes_per_tic - ignoring these for now
-  if (demorecording && logictic && dsda_command_history_size && !dsda_demo_version) {
+  if (demorecording && true_logictic && dsda_command_history_size && !dsda_demo_version) {
     const byte* p;
     int count;
 
-    count = MIN(logictic, dsda_command_history_size);
+    count = MIN(true_logictic, dsda_command_history_size);
 
     p = dsda_demo_write_buffer_p - bytes_per_tic * count;
 
@@ -264,7 +271,11 @@ void dsda_InitDemoRecording(void) {
 
   if (compatibility_level_unspecified)
     I_Error("You must specify a compatibility level when recording a demo!\n"
-            "Example: dsda-doom -iwad DOOM -complevel 3 -record demo");
+            "Example: dsda-doom -iwad DOOM -complevel 3 -skill 4 -record demo");
+
+  if (!dsda_Flag(dsda_arg_skill))
+    I_Error("You must specify a skill level when recording a demo!\n"
+            "Example: dsda-doom -iwad DOOM -complevel 3 -skill 4 -record demo");
 
   demorecording = true;
 
@@ -635,8 +646,11 @@ void dsda_JoinDemoCmd(ticcmd_t* cmd) {
 
   // Sometimes this bit is not available
   if (
-    (demo_compatibility && !prboom_comp[PC_ALLOW_SSG_DIRECT].state) ||
-    (cmd->buttons & BT_CHANGE) == 0
+    (!demo_compatibility || gamestate != GS_FINALE) &&
+    (
+      (demo_compatibility && !prboom_comp[PC_ALLOW_SSG_DIRECT].state) ||
+      (cmd->buttons & BT_CHANGE) == 0
+    )
   )
     cmd->buttons |= BT_JOIN;
   else
@@ -680,6 +694,11 @@ static const byte* dsda_ReadDSDADemoHeader(const byte* demo_p, const byte* heade
   else
     dsda_demo_header_data.flags = 0;
 
+  if (dsda_demo_version >= 3)
+    dsda_demo_header_data.udmf_version = *demo_p++;
+  else
+    dsda_demo_header_data.udmf_version = 0;
+
   dsda_EnableExCmd();
 
   if (dsda_demo_header_data.flags & DF_CASUAL_FEATURES)
@@ -763,6 +782,8 @@ void dsda_WriteDSDADemoHeader(byte** p) {
   if (dsda_AllowCasualExCmdFeatures())
     demo_p[8] |= DF_CASUAL_FEATURES;
 
+  demo_p[9] = DSDA_UDMF_VERSION;
+
   demo_p += dsda_demo_header_data_size[dsda_demo_version];
 
   *p = demo_p;
@@ -773,14 +794,15 @@ void dsda_ApplyDSDADemoFormat(byte** demo_p) {
 
   if (map_format.zdoom)
   {
-    if (!dsda_Flag(dsda_arg_baddemo))
-      I_Error("Experimental formats require the -baddemo option to record.");
-
     if (!mbf21)
-      I_Error("You must use complevel 21 when recording on doom-in-hexen format.");
+      I_Error("You must use complevel 21 when recording in advanced formats.");
 
     use_dsda_format = true;
   }
+  else if (dsda_UseMapinfo())
+  {
+    use_dsda_format = true;
+  }
 
   if (dsda_Flag(dsda_arg_dsdademo))
   {
