@@ -29,6 +29,7 @@ const byte* dsda_EvaluateDemoStartPoint(const byte* demo_p);
 void dsda_ExportDemo(const char* name);
 void dsda_MarkCompatibilityLevelUnspecified(void);
 int dsda_BytesPerTic(void);
+int dsda_DemoTic(void);
 void dsda_EvaluateBytesPerTic(void);
 void dsda_RestoreCommandHistory(void);
 void dsda_InitDemoRecording(void);
@@ -36,7 +37,7 @@ void dsda_WriteToDemo(const void* buffer, size_t length);
 void dsda_WriteQueueToDemo(const void* buffer, size_t length);
 void dsda_WriteTicToDemo(const void* buffer, size_t length);
 void dsda_WriteDemoToFile(void);
-dboolean dsda_CopyPendingCmd(ticcmd_t* cmd);
+dboolean dsda_CopyPendingCmd(ticcmd_t* cmd, int delta);
 void dsda_CopyPriorCmd(ticcmd_t* cmd, int delta);
 void dsda_QueueJoin(void);
 dboolean dsda_PendingJoin(void);
