@@ -451,14 +451,15 @@ static int dsda_ParseHUDConfig(char** hud_config, int line_i) {
       if (!strncmp(command, components[i].name, sizeof(command))) {
         int x, y;
         int vpt;
-        int component_args[4] = { 0 };
+        int component_args[6] = { 0 };
         char alignment[16];
 
         found = true;
 
-        count = sscanf(args, "%d %d %15s %d %d %d %d", &x, &y, alignment,
+        count = sscanf(args, "%d %d %15s %d %d %d %d %d %d", &x, &y, alignment,
                         &component_args[0], &component_args[1],
-                        &component_args[2], &component_args[3]);
+                        &component_args[2], &component_args[3],
+                        &component_args[4], &component_args[5]);
         if (count < 3)
           I_Error("Invalid hud component args \"%s\"", line);
 
@@ -544,16 +545,18 @@ static void dsda_LoadHUDConfig(void) {
     if (arg->found)
       length = M_ReadFileToString(arg->value.v_string, &hud_config);
 
-    lump = W_GetNumForName("DSDAHUD");
-
-    if (lump != -1) {
-      if (!hud_config)
+    lump = -1;
+    while ((lump = W_FindNumFromName("DSDAHUD", lump)) >= 0) {
+      if (!hud_config) {
         hud_config = W_ReadLumpToString(lump);
+        length = W_LumpLength(lump);
+      }
       else {
         hud_config = Z_Realloc(hud_config, length + W_LumpLength(lump) + 2);
         hud_config[length++] = '\n'; // in case the file didn't end in a new line
         W_ReadLump(lump, hud_config + length);
-        hud_config[length + W_LumpLength(lump)] = '\0';
+        length += W_LumpLength(lump);
+        hud_config[length] = '\0';
       }
     }
 
