@@ -67,6 +67,7 @@ int g_wp_pistol;
 int g_telefog_height;
 int g_thrust_factor;
 int g_fuzzy_aim_shift;
+int g_jump;
 
 int g_s_null;
 
@@ -159,7 +160,7 @@ static void dsda_InitDoom(void) {
   g_mt_player = MT_PLAYER;
   g_mt_tfog = MT_TFOG;
   g_mt_blood = MT_BLOOD;
-  g_skullpop_mt = MT_GIBDTH;
+  g_skullpop_mt = MT_NULL;
 
   g_wp_fist = wp_fist;
   g_wp_chainsaw = wp_chainsaw;
@@ -168,6 +169,7 @@ static void dsda_InitDoom(void) {
   g_telefog_height = 0;
   g_thrust_factor = 100;
   g_fuzzy_aim_shift = 20;
+  g_jump = 8;
 
   g_s_null = S_NULL;
 
@@ -310,6 +312,7 @@ static void dsda_InitHeretic(void) {
   g_telefog_height = TELEFOGHEIGHT;
   g_thrust_factor = 150;
   g_fuzzy_aim_shift = 21;
+  g_jump = 8;
 
   g_s_null = HERETIC_S_NULL;
 
@@ -467,6 +470,7 @@ static void dsda_InitHexen(void) {
   g_telefog_height = TELEFOGHEIGHT;
   g_thrust_factor = 150;
   g_fuzzy_aim_shift = 21;
+  g_jump = 9;
 
   g_s_null = HEXEN_S_NULL;
 
