@@ -18,9 +18,8 @@
 #ifndef __DSDA_HUD_COMPONENT_BIG_HEALTH__
 #define __DSDA_HUD_COMPONENT_BIG_HEALTH__
 
-void dsda_InitBigHealthHC(int x_offset, int y_offset, int vpt_flags);
-void dsda_UpdateBigHealthHC(void);
-void dsda_DrawBigHealthHC(void);
-void dsda_EraseBigHealthHC(void);
+void dsda_InitBigHealthHC(int x_offset, int y_offset, int vpt_flags, int* args, int arg_count, void** data);
+void dsda_UpdateBigHealthHC(void* data);
+void dsda_DrawBigHealthHC(void* data);
 
 #endif
