@@ -35,13 +35,10 @@ typedef struct {
   dboolean polyobjs;
   dboolean acs;
   dboolean thing_id;
-  dboolean mapinfo;
   dboolean sndseq;
-  dboolean sndinfo;
   dboolean animdefs;
   dboolean doublesky;
   dboolean map99;
-  dboolean lax_monster_activation;
   short generalized_mask;
   line_activation_t switch_activation;
   void (*init_sector_special)(sector_t*, int);
