@@ -21,43 +21,39 @@
 #include "doomstat.h"
 #include "m_misc.h"
 
+#include "dsda/args.h"
+#include "dsda/episode.h"
 #include "dsda/map_format.h"
+#include "dsda/mapinfo/doom.h"
 #include "dsda/mapinfo/hexen.h"
 #include "dsda/mapinfo/u.h"
 #include "dsda/mapinfo/legacy.h"
 
 #include "mapinfo.h"
 
+map_info_t map_info;
+
 int dsda_NameToMap(const char* name, int* episode, int* map) {
-  char name_upper[9];
-  int episode_from_name = -1;
-  int map_from_name = -1;
+  int found;
 
-  if (strlen(name) > 8)
-    return false;
+  if (dsda_DoomNameToMap(&found, name, episode, map))
+    return found;
 
-  strncpy(name_upper, name, 8);
-  name_upper[8] = 0;
-  M_Strupr(name_upper);
+  if (dsda_HexenNameToMap(&found, name, episode, map))
+    return found;
 
-  if (gamemode != commercial) {
-    if (sscanf(name_upper, "E%dM%d", &episode_from_name, &map_from_name) != 2)
-      return false;
-  }
-  else {
-    if (sscanf(name_upper, "MAP%d", &map_from_name) != 1)
-      return false;
+  if (dsda_UNameToMap(&found, name, episode, map))
+    return found;
 
-    episode_from_name = 1;
-  }
+  dsda_LegacyNameToMap(&found, name, episode, map);
 
-  *episode = episode_from_name;
-  *map = map_from_name;
-
-  return true;
+  return found;
 }
 
 void dsda_FirstMap(int* episode, int* map) {
+  if (dsda_DoomFirstMap(episode, map))
+    return;
+
   if (dsda_HexenFirstMap(episode, map))
     return;
 
@@ -68,6 +64,9 @@ void dsda_FirstMap(int* episode, int* map) {
 }
 
 void dsda_NewGameMap(int* episode, int* map) {
+  if (dsda_DoomNewGameMap(episode, map))
+    return;
+
   if (dsda_HexenNewGameMap(episode, map))
     return;
 
@@ -78,6 +77,9 @@ void dsda_NewGameMap(int* episode, int* map) {
 }
 
 void dsda_ResolveWarp(int* args, int arg_count, int* episode, int* map) {
+  if (dsda_DoomResolveWarp(args, arg_count, episode, map))
+    return;
+
   if (dsda_HexenResolveWarp(args, arg_count, episode, map))
     return;
 
@@ -88,6 +90,9 @@ void dsda_ResolveWarp(int* args, int arg_count, int* episode, int* map) {
 }
 
 void dsda_NextMap(int* episode, int* map) {
+  if (dsda_DoomNextMap(episode, map))
+    return;
+
   if (dsda_HexenNextMap(episode, map))
     return;
 
@@ -98,6 +103,9 @@ void dsda_NextMap(int* episode, int* map) {
 }
 
 void dsda_ShowNextLocBehaviour(int* behaviour) {
+  if (dsda_DoomShowNextLocBehaviour(behaviour))
+    return;
+
   if (dsda_HexenShowNextLocBehaviour(behaviour))
     return;
 
@@ -110,6 +118,9 @@ void dsda_ShowNextLocBehaviour(int* behaviour) {
 int dsda_SkipDrawShowNextLoc(void) {
   int skip;
 
+  if (dsda_DoomSkipDrawShowNextLoc(&skip))
+    return skip;
+
   if (dsda_HexenSkipDrawShowNextLoc(&skip))
     return skip;
 
@@ -121,10 +132,88 @@ int dsda_SkipDrawShowNextLoc(void) {
   return skip;
 }
 
+static fixed_t dsda_Gravity(void) {
+  fixed_t gravity;
+
+  if (dsda_DoomGravity(&gravity))
+    return gravity;
+
+  if (dsda_HexenGravity(&gravity))
+    return gravity;
+
+  if (dsda_UGravity(&gravity))
+    return gravity;
+
+  dsda_LegacyGravity(&gravity);
+
+  return gravity;
+}
+
+static fixed_t dsda_AirControl(void) {
+  fixed_t air_control;
+
+  if (dsda_DoomAirControl(&air_control))
+    return air_control;
+
+  if (dsda_HexenAirControl(&air_control))
+    return air_control;
+
+  if (dsda_UAirControl(&air_control))
+    return air_control;
+
+  dsda_LegacyAirControl(&air_control);
+
+  return air_control;
+}
+
+static map_info_flags_t dsda_MapFlags(void) {
+  map_info_flags_t flags;
+
+  if (dsda_DoomMapFlags(&flags))
+    return flags;
+
+  if (dsda_HexenMapFlags(&flags))
+    return flags;
+
+  if (dsda_UMapFlags(&flags))
+    return flags;
+
+  dsda_LegacyMapFlags(&flags);
+
+  return flags;
+}
+
+static int dsda_MapColorMap(void) {
+  int colormap;
+
+  if (dsda_DoomMapColorMap(&colormap))
+    return colormap;
+
+  if (dsda_HexenMapColorMap(&colormap))
+    return colormap;
+
+  if (dsda_UMapColorMap(&colormap))
+    return colormap;
+
+  dsda_LegacyMapColorMap(&colormap);
+
+  return colormap;
+}
+
 static void dsda_UpdateMapInfo(void) {
+  dsda_DoomUpdateMapInfo();
   dsda_HexenUpdateMapInfo();
   dsda_UUpdateMapInfo();
   dsda_LegacyUpdateMapInfo();
+
+  map_info.flags = dsda_MapFlags();
+  map_info.default_colormap = dsda_MapColorMap();
+  map_info.gravity = dsda_Gravity();
+  map_info.air_control = dsda_AirControl();
+  // This formula is based on 256 -> 65536 (no friction) and 65536 -> 0xe800 (normal friction)
+  map_info.air_friction = map_info.air_control > 256 ?
+                          65560 - FixedMul(map_info.air_control, 6168) :
+                          FRACUNIT;
 }
 
 void dsda_UpdateGameMap(int episode, int map) {
@@ -133,6 +222,10 @@ void dsda_UpdateGameMap(int episode, int map) {
   dsda_UpdateMapInfo();
 }
 
+void dsda_ResetAirControl(void) {
+  map_info.air_control = dsda_AirControl();
+}
+
 void dsda_ResetLeaveData(void) {
   memset(&leave_data, 0, sizeof(leave_data));
 }
@@ -149,12 +242,14 @@ dboolean dsda_FinaleShortcut(void) {
 }
 
 void dsda_UpdateLastMapInfo(void) {
+  dsda_DoomUpdateLastMapInfo();
   dsda_HexenUpdateLastMapInfo();
   dsda_UUpdateLastMapInfo();
   dsda_LegacyUpdateLastMapInfo();
 }
 
 void dsda_UpdateNextMapInfo(void) {
+  dsda_DoomUpdateNextMapInfo();
   dsda_HexenUpdateNextMapInfo();
   dsda_UUpdateNextMapInfo();
   dsda_LegacyUpdateNextMapInfo();
@@ -163,6 +258,9 @@ void dsda_UpdateNextMapInfo(void) {
 int dsda_ResolveCLEV(int* episode, int* map) {
   int clev;
 
+  if (dsda_DoomResolveCLEV(&clev, episode, map))
+    return clev;
+
   if (dsda_HexenResolveCLEV(&clev, episode, map))
     return clev;
 
@@ -177,6 +275,9 @@ int dsda_ResolveCLEV(int* episode, int* map) {
 int dsda_ResolveINIT(void) {
   int init;
 
+  if (dsda_DoomResolveINIT(&init))
+    return init;
+
   if (dsda_HexenResolveINIT(&init))
     return init;
 
@@ -191,6 +292,9 @@ int dsda_ResolveINIT(void) {
 int dsda_MusicIndexToLumpNum(int music_index) {
   int lump;
 
+  if (dsda_DoomMusicIndexToLumpNum(&lump, music_index))
+    return lump;
+
   if (dsda_HexenMusicIndexToLumpNum(&lump, music_index))
     return lump;
 
@@ -203,6 +307,9 @@ int dsda_MusicIndexToLumpNum(int music_index) {
 }
 
 void dsda_MapMusic(int* music_index, int* music_lump) {
+  if (dsda_DoomMapMusic(music_index, music_lump))
+    return;
+
   if (dsda_HexenMapMusic(music_index, music_lump))
     return;
 
@@ -212,7 +319,23 @@ void dsda_MapMusic(int* music_index, int* music_lump) {
   dsda_LegacyMapMusic(music_index, music_lump);
 }
 
+void dsda_IntermissionMusic(int* music_index, int* music_lump) {
+  if (dsda_DoomIntermissionMusic(music_index, music_lump))
+    return;
+
+  if (dsda_HexenIntermissionMusic(music_index, music_lump))
+    return;
+
+  if (dsda_UIntermissionMusic(music_index, music_lump))
+    return;
+
+  dsda_LegacyIntermissionMusic(music_index, music_lump);
+}
+
 void dsda_InterMusic(int* music_index, int* music_lump) {
+  if (dsda_DoomInterMusic(music_index, music_lump))
+    return;
+
   if (dsda_HexenInterMusic(music_index, music_lump))
     return;
 
@@ -226,11 +349,17 @@ typedef enum {
   finale_owner_legacy,
   finale_owner_u,
   finale_owner_hexen,
+  finale_owner_doom,
 } finale_owner_t;
 
 static finale_owner_t finale_owner = finale_owner_legacy;
 
 void dsda_StartFinale(void) {
+  if (dsda_DoomStartFinale()) {
+    finale_owner = finale_owner_doom;
+    return;
+  }
+
   if (dsda_HexenStartFinale()) {
     finale_owner = finale_owner_hexen;
     return;
@@ -246,6 +375,13 @@ void dsda_StartFinale(void) {
 }
 
 int dsda_FTicker(void) {
+  if (finale_owner == finale_owner_doom) {
+    if (!dsda_DoomFTicker())
+      finale_owner = finale_owner_legacy;
+
+    return true;
+  }
+
   if (finale_owner == finale_owner_hexen) {
     if (!dsda_HexenFTicker())
       finale_owner = finale_owner_legacy;
@@ -265,6 +401,12 @@ int dsda_FTicker(void) {
 }
 
 int dsda_FDrawer(void) {
+  if (finale_owner == finale_owner_doom) {
+    dsda_DoomFDrawer();
+
+    return true;
+  }
+
   if (finale_owner == finale_owner_hexen) {
     dsda_HexenFDrawer();
 
@@ -282,6 +424,9 @@ int dsda_FDrawer(void) {
 }
 
 int dsda_BossAction(mobj_t* mo) {
+  if (dsda_DoomBossAction(mo))
+    return true;
+
   if (dsda_HexenBossAction(mo))
     return true;
 
@@ -292,7 +437,27 @@ int dsda_BossAction(mobj_t* mo) {
   return false;
 }
 
+const char* dsda_MapLumpName(int episode, int map) {
+  const char* name;
+
+  if (dsda_DoomMapLumpName(&name, episode, map))
+    return name;
+
+  if (dsda_HexenMapLumpName(&name, episode, map))
+    return name;
+
+  if (dsda_UMapLumpName(&name, episode, map))
+    return name;
+
+  dsda_LegacyMapLumpName(&name, episode, map);
+
+  return name;
+}
+
 void dsda_HUTitle(dsda_string_t* str) {
+  if (dsda_DoomHUTitle(str))
+    return;
+
   if (dsda_HexenHUTitle(str))
     return;
 
@@ -302,9 +467,29 @@ void dsda_HUTitle(dsda_string_t* str) {
   dsda_LegacyHUTitle(str);
 }
 
+const char* dsda_MapAuthor(void) {
+  const char* author;
+
+  if (dsda_DoomMapAuthor(&author))
+    return author;
+
+  if (dsda_HexenMapAuthor(&author))
+    return author;
+
+  if (dsda_UMapAuthor(&author))
+    return author;
+
+  dsda_LegacyMapAuthor(&author);
+
+  return author;
+}
+
 int dsda_SkyTexture(void) {
   int sky;
 
+  if (dsda_DoomSkyTexture(&sky))
+    return sky;
+
   if (dsda_HexenSkyTexture(&sky))
     return sky;
 
@@ -317,6 +502,9 @@ int dsda_SkyTexture(void) {
 }
 
 void dsda_PrepareInitNew(void) {
+  if (dsda_DoomPrepareInitNew())
+    return;
+
   if (dsda_HexenPrepareInitNew())
     return;
 
@@ -327,6 +515,9 @@ void dsda_PrepareInitNew(void) {
 }
 
 void dsda_PrepareIntermission(int* behaviour) {
+  if (dsda_DoomPrepareIntermission(behaviour))
+    return;
+
   if (dsda_HexenPrepareIntermission(behaviour))
     return;
 
@@ -337,6 +528,9 @@ void dsda_PrepareIntermission(int* behaviour) {
 }
 
 void dsda_PrepareFinale(int* behaviour) {
+  if (dsda_DoomPrepareFinale(behaviour))
+    return;
+
   if (dsda_HexenPrepareFinale(behaviour))
     return;
 
@@ -347,14 +541,22 @@ void dsda_PrepareFinale(int* behaviour) {
 }
 
 void dsda_LoadMapInfo(void) {
+  dsda_AddOriginalEpisodes();
+
+  dsda_DoomLoadMapInfo();
   dsda_HexenLoadMapInfo();
   dsda_ULoadMapInfo();
   dsda_LegacyLoadMapInfo();
+
+  dsda_AddCustomEpisodes();
 }
 
 const char* dsda_ExitPic(void) {
   const char* exit_pic;
 
+  if (dsda_DoomExitPic(&exit_pic))
+    return exit_pic;
+
   if (dsda_HexenExitPic(&exit_pic))
     return exit_pic;
 
@@ -368,6 +570,9 @@ const char* dsda_ExitPic(void) {
 const char* dsda_EnterPic(void) {
   const char* enter_pic;
 
+  if (dsda_DoomEnterPic(&enter_pic))
+    return enter_pic;
+
   if (dsda_HexenEnterPic(&enter_pic))
     return enter_pic;
 
@@ -378,7 +583,26 @@ const char* dsda_EnterPic(void) {
   return enter_pic;
 }
 
+const char* dsda_BorderTexture(void) {
+  const char* border_texture;
+
+  if (dsda_DoomBorderTexture(&border_texture))
+    return border_texture;
+
+  if (dsda_HexenBorderTexture(&border_texture))
+    return border_texture;
+
+  if (dsda_UBorderTexture(&border_texture))
+    return border_texture;
+
+  dsda_LegacyBorderTexture(&border_texture);
+  return border_texture;
+}
+
 void dsda_PrepareEntering(void) {
+  if (dsda_DoomPrepareEntering())
+    return;
+
   if (dsda_HexenPrepareEntering())
     return;
 
@@ -389,6 +613,9 @@ void dsda_PrepareEntering(void) {
 }
 
 void dsda_PrepareFinished(void) {
+  if (dsda_DoomPrepareFinished())
+    return;
+
   if (dsda_HexenPrepareFinished())
     return;
 
@@ -401,6 +628,9 @@ void dsda_PrepareFinished(void) {
 int dsda_MapLightning(void) {
   int lightning;
 
+  if (dsda_DoomMapLightning(&lightning))
+    return lightning;
+
   if (dsda_HexenMapLightning(&lightning))
     return lightning;
 
@@ -413,6 +643,9 @@ int dsda_MapLightning(void) {
 }
 
 void dsda_ApplyFadeTable(void) {
+  if (dsda_DoomApplyFadeTable())
+    return;
+
   if (dsda_HexenApplyFadeTable())
     return;
 
@@ -425,6 +658,9 @@ void dsda_ApplyFadeTable(void) {
 int dsda_MapCluster(int map) {
   int cluster;
 
+  if (dsda_DoomMapCluster(&cluster, map))
+    return cluster;
+
   if (dsda_HexenMapCluster(&cluster, map))
     return cluster;
 
@@ -439,6 +675,9 @@ int dsda_MapCluster(int map) {
 short dsda_Sky1Texture(void) {
   short texture;
 
+  if (dsda_DoomSky1Texture(&texture))
+    return texture;
+
   if (dsda_HexenSky1Texture(&texture))
     return texture;
 
@@ -453,6 +692,9 @@ short dsda_Sky1Texture(void) {
 short dsda_Sky2Texture(void) {
   short texture;
 
+  if (dsda_DoomSky2Texture(&texture))
+    return texture;
+
   if (dsda_HexenSky2Texture(&texture))
     return texture;
 
@@ -465,6 +707,9 @@ short dsda_Sky2Texture(void) {
 }
 
 void dsda_InitSky(void) {
+  if (dsda_DoomInitSky())
+    return;
+
   if (dsda_HexenInitSky())
     return;
 
