@@ -31,6 +31,35 @@
 #define WD_VICTORY      0x01
 #define WD_START_FINALE 0x02
 
+#define MI_INTERMISSION                   0x00000001ul
+#define MI_ALLOW_MONSTER_TELEFRAGS        0x00000002ul
+#define MI_ACTIVATE_OWN_DEATH_SPECIALS    0x00000004ul
+#define MI_LAX_MONSTER_ACTIVATION         0x00000008ul
+#define MI_MISSILES_ACTIVATE_IMPACT_LINES 0x00000010ul
+#define MI_FILTER_STARTS                  0x00000020ul
+#define MI_ALLOW_RESPAWN                  0x00000040ul
+#define MI_ALLOW_JUMP                     0x00000080ul
+#define MI_CHECK_SWITCH_RANGE             0x00000200ul
+#define MI_RESET_HEALTH                   0x00000400ul
+#define MI_RESET_INVENTORY                0x00000800ul
+#define MI_USE_PLAYER_START_Z             0x00001000ul
+#define MI_SHOW_AUTHOR                    0x00008000ul
+#define MI_PASSOVER                       0x00010000ul
+#define MI_EVEN_LIGHTING                  0x00020000ul
+#define MI_SMOOTH_LIGHTING                0x00040000ul
+
+typedef uint32_t map_info_flags_t;
+
+typedef struct {
+  fixed_t gravity;
+  fixed_t air_control;
+  fixed_t air_friction;
+  int default_colormap;
+  map_info_flags_t flags;
+} map_info_t;
+
+extern map_info_t map_info;
+
 void dsda_FirstMap(int* episode, int* map);
 void dsda_NewGameMap(int* episode, int* map);
 void dsda_ResolveWarp(int* args, int arg_count, int* episode, int* map);
@@ -48,11 +77,14 @@ int dsda_ResolveCLEV(int* episode, int* map);
 int dsda_ResolveINIT(void);
 int dsda_MusicIndexToLumpNum(int music_index);
 void dsda_MapMusic(int* music_index, int* music_lump);
+void dsda_IntermissionMusic(int* music_index, int* music_lump);
 void dsda_InterMusic(int* music_index, int* music_lump);
 void dsda_StartFinale(void);
 int dsda_FTicker(void);
 int dsda_FDrawer(void);
 int dsda_BossAction(mobj_t* mo);
+const char* dsda_MapLumpName(int episode, int map);
+const char* dsda_MapAuthor(void);
 void dsda_HUTitle(dsda_string_t* str);
 int dsda_SkyTexture(void);
 void dsda_PrepareInitNew(void);
@@ -61,6 +93,7 @@ void dsda_PrepareFinale(int* behaviour);
 void dsda_LoadMapInfo(void);
 const char* dsda_ExitPic(void);
 const char* dsda_EnterPic(void);
+const char* dsda_BorderTexture(void);
 void dsda_PrepareEntering(void);
 void dsda_PrepareFinished(void);
 int dsda_MapLightning(void);
