@@ -20,8 +20,10 @@
 
 #include "p_mobj.h"
 
+#include "dsda/mapinfo.h"
 #include "dsda/utility.h"
 
+int dsda_HexenNameToMap(int* found, const char* name, int* episode, int* map);
 int dsda_HexenFirstMap(int* episode, int* map);
 int dsda_HexenNewGameMap(int* episode, int* map);
 int dsda_HexenResolveWarp(int* args, int arg_count, int* episode, int* map);
@@ -35,11 +37,14 @@ int dsda_HexenResolveCLEV(int* clev, int* episode, int* map);
 int dsda_HexenResolveINIT(int* init);
 int dsda_HexenMusicIndexToLumpNum(int* lump, int music_index);
 int dsda_HexenMapMusic(int* music_index, int* music_lump);
+int dsda_HexenIntermissionMusic(int* music_index, int* music_lump);
 int dsda_HexenInterMusic(int* music_index, int* music_lump);
 int dsda_HexenStartFinale(void);
 int dsda_HexenFTicker(void);
 void dsda_HexenFDrawer(void);
 int dsda_HexenBossAction(mobj_t* mo);
+int dsda_HexenMapLumpName(const char** name, int episode, int map);
+int dsda_HexenMapAuthor(const char** author);
 int dsda_HexenHUTitle(dsda_string_t* str);
 int dsda_HexenSkyTexture(int* sky);
 int dsda_HexenPrepareInitNew(void);
@@ -48,6 +53,7 @@ int dsda_HexenPrepareFinale(int* result);
 void dsda_HexenLoadMapInfo(void);
 int dsda_HexenExitPic(const char** exit_pic);
 int dsda_HexenEnterPic(const char** enter_pic);
+int dsda_HexenBorderTexture(const char** border_texture);
 int dsda_HexenPrepareEntering(void);
 int dsda_HexenPrepareFinished(void);
 int dsda_HexenMapLightning(int* lightning);
@@ -55,6 +61,10 @@ int dsda_HexenApplyFadeTable(void);
 int dsda_HexenMapCluster(int* cluster, int map);
 int dsda_HexenSky1Texture(short* texture);
 int dsda_HexenSky2Texture(short* texture);
+int dsda_HexenGravity(fixed_t* gravity);
+int dsda_HexenAirControl(fixed_t* air_control);
 int dsda_HexenInitSky(void);
+int dsda_HexenMapFlags(map_info_flags_t* flags);
+int dsda_HexenMapColorMap(int* colormap);
 
 #endif
