@@ -20,8 +20,10 @@
 
 #include "p_mobj.h"
 
+#include "dsda/mapinfo.h"
 #include "dsda/utility.h"
 
+int dsda_LegacyNameToMap(int* found, const char* name, int* episode, int* map);
 int dsda_LegacyFirstMap(int* episode, int* map);
 int dsda_LegacyNewGameMap(int* episode, int* map);
 int dsda_LegacyResolveWarp(int* args, int arg_count, int* episode, int* map);
@@ -35,11 +37,14 @@ int dsda_LegacyResolveCLEV(int* clev, int* episode, int* map);
 int dsda_LegacyResolveINIT(int* init);
 int dsda_LegacyMusicIndexToLumpNum(int* lump, int music_index);
 int dsda_LegacyMapMusic(int* music_index, int* music_lump);
+int dsda_LegacyIntermissionMusic(int* music_index, int* music_lump);
 int dsda_LegacyInterMusic(int* music_index, int* music_lump);
 int dsda_LegacyStartFinale(void);
 int dsda_LegacyFTicker(void);
 void dsda_LegacyFDrawer(void);
 int dsda_LegacyBossAction(mobj_t* mo);
+int dsda_LegacyMapLumpName(const char** name, int episode, int map);
+int dsda_LegacyMapAuthor(const char** author);
 int dsda_LegacyHUTitle(dsda_string_t* str);
 int dsda_LegacySkyTexture(int* sky);
 int dsda_LegacyPrepareInitNew(void);
@@ -48,6 +53,7 @@ int dsda_LegacyPrepareFinale(int* result);
 void dsda_LegacyLoadMapInfo(void);
 int dsda_LegacyExitPic(const char** exit_pic);
 int dsda_LegacyEnterPic(const char** enter_pic);
+int dsda_LegacyBorderTexture(const char** border_texture);
 int dsda_LegacyPrepareEntering(void);
 int dsda_LegacyPrepareFinished(void);
 int dsda_LegacyMapLightning(int* lightning);
@@ -55,6 +61,10 @@ int dsda_LegacyApplyFadeTable(void);
 int dsda_LegacyMapCluster(int* cluster, int map);
 int dsda_LegacySky1Texture(short* texture);
 int dsda_LegacySky2Texture(short* texture);
+int dsda_LegacyGravity(fixed_t* gravity);
+int dsda_LegacyAirControl(fixed_t* air_control);
 int dsda_LegacyInitSky(void);
+int dsda_LegacyMapFlags(map_info_flags_t* flags);
+int dsda_LegacyMapColorMap(int* colormap);
 
 #endif
