@@ -211,8 +211,7 @@ int G_ReloadLevel(void)
   int result = false;
 
   if ((gamestate == GS_LEVEL || gamestate == GS_INTERMISSION) &&
-      !deathmatch && !netgame &&
-      !demorecording && !demoplayback &&
+      allow_incompatibility &&
       !menuactive)
   {
     G_DeferedInitNew(gameskill, gameepisode, gamemap);
@@ -238,8 +237,7 @@ int G_GotoNextLevel(void)
   dsda_NextMap(&epsd, &map);
 
   if ((gamestate == GS_LEVEL) &&
-    !deathmatch && !netgame &&
-    !demorecording && !demoplayback &&
+    allow_incompatibility &&
     !menuactive)
   {
     G_DeferedInitNew(gameskill, epsd, map);
@@ -461,7 +459,7 @@ void e6y_G_DoCompleted(void)
 
   memset(&stats[numlevels], 0, sizeof(timetable_t));
 
-  strcpy(stats[numlevels].map, MAPNAME(gameepisode, gamemap));
+  snprintf(stats[numlevels].map, sizeof(stats[numlevels].map), "%s", dsda_MapLumpName(gameepisode, gamemap));
 
   if (secretexit)
   {
