@@ -35,6 +35,7 @@
 #include "doomstat.h"
 #include "d_event.h"
 #include "g_game.h"
+#include "lprintf.h"
 #include "v_video.h"
 #include "w_wad.h"
 #include "s_sound.h"
@@ -71,7 +72,6 @@ const char*   finalepatch;
 // Ty 03/22/98 - ... the new s_WHATEVER extern variables are used
 // in the code below instead.
 
-void    F_StartCast (void);
 void    F_CastTicker (void);
 dboolean F_CastResponder (event_t *ev);
 void    F_CastDrawer (void);
@@ -288,7 +288,7 @@ float Get_TextSpeed(void)
 static dboolean F_ShowCast(void)
 {
   return gamemap == 30 ||
-         (gamemission == pack_nerve && singleplayer && gamemap == 8) ||
+         (gamemission == pack_nerve && allow_incompatibility && gamemap == 8) ||
          dsda_FinaleShortcut();
 }
 
@@ -327,18 +327,17 @@ void F_Ticker(void)
           (midstage && acceleratestage)) {
         if (gamemode != commercial)       // Doom 1 / Ultimate Doom episode end
           {                               // with enough time, it's automatic
-            finalecount = 0;
-            finalestage = 1;
-            wipegamestate = -1;         // force a wipe
             if (gameepisode == 3)
-              S_StartMusic(mus_bunny);
+              F_StartScroll(NULL, NULL, NULL, true);
+            else
+              F_StartPostFinale();
           }
         else   // you must press a button to continue in Doom 2
           if (!demo_compatibility && midstage)
             {
             next_level:
               if (F_ShowCast())
-                F_StartCast();              // cast of Doom 2 characters
+                F_StartCast(NULL, NULL, true); // cast of Doom 2 characters
               else
                 gameaction = ga_worlddone;  // next level, e.g. MAP07
             }
@@ -364,7 +363,7 @@ void F_TextWrite (void)
 {
   if (finalepatch)
   {
-    V_FillBorder(-1, 0);
+    V_ClearBorder();
     V_DrawNamePatch(0, 0, 0, finalepatch, CR_DEFAULT, VPT_STRETCH);
   }
   else
@@ -420,7 +419,7 @@ typedef struct
   mobjtype_t   type;
 } castinfo_t;
 
-static const castinfo_t castorder[] = { // CPhipps - static const, initialised here
+static const castinfo_t castorder_d2[] = {
   { &s_CC_ZOMBIE,  MT_POSSESSED },
   { &s_CC_SHOTGUN, MT_SHOTGUY },
   { &s_CC_HEAVY,   MT_CHAINGUY },
@@ -438,24 +437,61 @@ static const castinfo_t castorder[] = { // CPhipps - static const, initialised h
   { &s_CC_SPIDER,  MT_SPIDER },
   { &s_CC_CYBER,   MT_CYBORG },
   { &s_CC_HERO,    MT_PLAYER },
-  { NULL,         0}
-  };
+  { NULL,          0 }
+};
 
-int             castnum;
-int             casttics;
-state_t*        caststate;
-dboolean         castdeath;
-int             castframes;
-int             castonmelee;
-dboolean         castattacking;
+static const castinfo_t castorder_d1[] = {
+  { &s_CC_ZOMBIE,  MT_POSSESSED },
+  { &s_CC_SHOTGUN, MT_SHOTGUY },
+  { &s_CC_IMP,     MT_TROOP },
+  { &s_CC_DEMON,   MT_SERGEANT },
+  { &s_CC_LOST,    MT_SKULL },
+  { &s_CC_CACO,    MT_HEAD },
+  { &s_CC_BARON,   MT_BRUISER },
+  { &s_CC_SPIDER,  MT_SPIDER },
+  { &s_CC_CYBER,   MT_CYBORG },
+  { &s_CC_HERO,    MT_PLAYER },
+  { NULL,          0 }
+};
 
+static const castinfo_t *castorder = castorder_d2;
+
+static int castnum;
+static int casttics;
+static state_t* caststate;
+static dboolean castdeath;
+static int castframes;
+static int castonmelee;
+static dboolean castattacking;
+static const char *castbackground;
 
 //
 // F_StartCast
 //
 
-void F_StartCast (void)
+static void F_StartCastMusic(const char* music, dboolean loop_music)
 {
+  if (music)
+  {
+    if (!S_ChangeMusicByName(music, loop_music))
+      lprintf(LO_WARN, "Finale cast music not found: %s\n", music);
+  }
+  else if (gamemode == commercial)
+  {
+    S_ChangeMusic(mus_evil, loop_music);
+  }
+  else
+  {
+    lprintf(LO_WARN, "Finale cast music unspecified\n");
+    S_StopMusic();
+  }
+}
+
+void F_StartCast (const char* background, const char* music, dboolean loop_music)
+{
+  castorder = (gamemode == commercial ? castorder_d2 : castorder_d1);
+  castbackground = (background ? background : bgcastcall);
+
   wipegamestate = -1;         // force a screen wipe
   castnum = 0;
   caststate = &states[mobjinfo[castorder[castnum].type].seestate];
@@ -465,9 +501,9 @@ void F_StartCast (void)
   castframes = 0;
   castonmelee = 0;
   castattacking = false;
-  S_ChangeMusic(mus_evil, true);
-}
 
+  F_StartCastMusic(music, loop_music);
+}
 
 //
 // F_CastTicker
@@ -663,10 +699,10 @@ void F_CastDrawer (void)
   dboolean             flip;
 
   // e6y: wide-res
-  V_FillBorder(-1, 0);
+  V_ClearBorder();
   // erase the entire screen to a background
   // CPhipps - patch drawing updated
-  V_DrawNamePatch(0,0,0, bgcastcall, CR_DEFAULT, VPT_STRETCH); // Ty 03/30/98 bg texture extern
+  V_DrawNamePatch(0,0,0, castbackground, CR_DEFAULT, VPT_STRETCH); // Ty 03/30/98 bg texture extern
 
   F_CastPrint (*(castorder[castnum].name));
 
@@ -684,8 +720,36 @@ void F_CastDrawer (void)
 //
 // F_BunnyScroll
 //
-static const char pfub2[] = { "PFUB2" };
-static const char pfub1[] = { "PFUB1" };
+static const char* pfub1 = "PFUB1";
+static const char* pfub2 = "PFUB2";
+
+static const char* scrollpic1;
+static const char* scrollpic2;
+
+static void F_StartScrollMusic(const char* music, dboolean loop_music)
+{
+  if (music) {
+    if (!S_ChangeMusicByName(music, loop_music))
+      lprintf(LO_WARN, "Finale scroll music not found: %s\n", music);
+  }
+  else if (W_LumpNameExists("D_BUNNY"))
+    S_ChangeMusic(mus_bunny, loop_music);
+  else {
+    lprintf(LO_WARN, "Finale scroll music unspecified\n");
+    S_StopMusic();
+  }
+}
+
+void F_StartScroll (const char* right, const char* left, const char* music, dboolean loop_music)
+{
+  wipegamestate = -1; // force a wipe
+  scrollpic1 = right ? right : pfub1;
+  scrollpic2 = left ? left : pfub2;
+  finalecount = 0;
+  finalestage = 1;
+
+  F_StartScrollMusic(music, loop_music);
+}
 
 void F_BunnyScroll (void)
 {
@@ -697,8 +761,8 @@ void F_BunnyScroll (void)
   if (finalecount == 0)
   {
     const rpatch_t *p1, *p2;
-    p1 = R_PatchByName(pfub1);
-    p2 = R_PatchByName(pfub2);
+    p1 = R_PatchByName(scrollpic1);
+    p2 = R_PatchByName(scrollpic2);
 
     p2width = p2->width;
     if (p1->width == 320)
@@ -716,19 +780,22 @@ void F_BunnyScroll (void)
   {
     int scrolled = 320 - (finalecount-230)/2;
     if (scrolled <= 0) {
-      V_DrawNamePatch(0, 0, 0, pfub2, CR_DEFAULT, VPT_STRETCH);
+      V_DrawNamePatch(0, 0, 0, scrollpic2, CR_DEFAULT, VPT_STRETCH);
     } else if (scrolled >= 320) {
-      V_DrawNamePatch(p1offset, 0, 0, pfub1, CR_DEFAULT, VPT_STRETCH);
+      V_DrawNamePatch(p1offset, 0, 0, scrollpic1, CR_DEFAULT, VPT_STRETCH);
       if (p1offset > 0)
-        V_DrawNamePatch(-320, 0, 0, pfub2, CR_DEFAULT, VPT_STRETCH);
+        V_DrawNamePatch(-320, 0, 0, scrollpic2, CR_DEFAULT, VPT_STRETCH);
     } else {
-      V_DrawNamePatch(p1offset + 320 - scrolled, 0, 0, pfub1, CR_DEFAULT, VPT_STRETCH);
-      V_DrawNamePatch(-scrolled, 0, 0, pfub2, CR_DEFAULT, VPT_STRETCH);
+      V_DrawNamePatch(p1offset + 320 - scrolled, 0, 0, scrollpic1, CR_DEFAULT, VPT_STRETCH);
+      V_DrawNamePatch(-scrolled, 0, 0, scrollpic2, CR_DEFAULT, VPT_STRETCH);
     }
     if (p2width == 320)
-      V_FillBorder(-1, 0);
+      V_ClearBorder();
   }
 
+  if (gamemode == commercial)
+    return;
+
   if (finalecount < 1130)
     return;
   if (finalecount < 1180)
@@ -753,6 +820,12 @@ void F_BunnyScroll (void)
   V_DrawNamePatch((320-13*8)/2, (200-8*8)/2, 0, name, CR_DEFAULT, VPT_STRETCH);
 }
 
+void F_StartPostFinale (void)
+{
+  finalecount = 0;
+  finalestage = 1;
+  wipegamestate = -1; // force a wipe
+}
 
 //
 // F_Drawer
@@ -778,7 +851,7 @@ void F_Drawer (void)
   else
   {
     // e6y: wide-res
-    V_FillBorder(-1, 0);
+    V_ClearBorder();
 
     switch (gameepisode)
     {
