@@ -72,6 +72,8 @@
 #include "p_spec.h"
 #include "e6y.h"
 
+#include "dsda/mapinfo.h"
+
 int imageformats[5] = {0, GL_LUMINANCE, GL_LUMINANCE_ALPHA, GL_RGB, GL_RGBA};
 
 /* TEXTURES */
@@ -943,6 +945,7 @@ void gld_BindTexture(GLTexture *gltexture, unsigned int flags, dboolean sky)
   {
     glBindTexture(GL_TEXTURE_2D, *gltexture->texid_p);
     gld_SetTexClamp(gltexture, flags);
+    glsl_SetTextureDims(0, gltexture->realtexwidth, gltexture->realtexheight);
     return;
   }
 
@@ -974,6 +977,7 @@ void gld_BindTexture(GLTexture *gltexture, unsigned int flags, dboolean sky)
   gld_BuildTexture(gltexture, buffer, false, gltexture->buffer_width, gltexture->buffer_height);
 
   gld_SetTexClamp(gltexture, flags);
+  glsl_SetTextureDims(0, gltexture->realtexwidth, gltexture->realtexheight);
 }
 
 GLTexture *gld_RegisterPatch(int lump, int cm, dboolean is_sprite, dboolean indexed)
@@ -1057,6 +1061,7 @@ void gld_BindPatch(GLTexture *gltexture, int cm)
   {
     glBindTexture(GL_TEXTURE_2D, *gltexture->texid_p);
     gld_SetTexClamp(gltexture, GLTEXTURE_CLAMPXY);
+    glsl_SetTextureDims(0, gltexture->realtexwidth, gltexture->realtexheight);
     return;
   }
 
@@ -1072,6 +1077,7 @@ void gld_BindPatch(GLTexture *gltexture, int cm)
   gld_BuildTexture(gltexture, buffer, false, gltexture->buffer_width, gltexture->buffer_height);
 
   gld_SetTexClamp(gltexture, GLTEXTURE_CLAMPXY);
+  glsl_SetTextureDims(0, gltexture->realtexwidth, gltexture->realtexheight);
 }
 
 GLTexture *gld_RegisterRaw(int lump, int width, int height, dboolean mipmap, dboolean indexed)
@@ -1148,6 +1154,7 @@ void gld_BindRaw(GLTexture *gltexture, unsigned int flags)
   {
     glBindTexture(GL_TEXTURE_2D, *gltexture->texid_p);
     gld_SetTexClamp(gltexture, flags);
+    glsl_SetTextureDims(0, gltexture->realtexwidth, gltexture->realtexheight);
     return;
   }
 
@@ -1162,6 +1169,7 @@ void gld_BindRaw(GLTexture *gltexture, unsigned int flags)
   gld_BuildTexture(gltexture, buffer, false, gltexture->buffer_width, gltexture->buffer_height);
 
   gld_SetTexClamp(gltexture, flags);
+  glsl_SetTextureDims(0, gltexture->realtexwidth, gltexture->realtexheight);
 }
 
 
@@ -1271,6 +1279,7 @@ void gld_BindColormapTexture(GLTexture *gltexture, int palette_index, int gamma_
   {
     glBindTexture(GL_TEXTURE_2D, *gltexture->texid_p);
     GLEXT_glActiveTextureARB(GL_TEXTURE0_ARB);
+    glsl_SetTextureDims(2, gltexture->realtexwidth, gltexture->realtexheight);
     return;
   }
 
@@ -1289,6 +1298,7 @@ void gld_BindColormapTexture(GLTexture *gltexture, int palette_index, int gamma_
 
   // 'pop' the active texture back to the default.
   GLEXT_glActiveTextureARB(GL_TEXTURE0_ARB);
+  glsl_SetTextureDims(2, gltexture->realtexwidth, gltexture->realtexheight);
 }
 
 void gld_InitColormapTextures(dboolean fullbright)
@@ -1355,6 +1365,8 @@ void gld_InitFuzzTexture(void)
     glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
 
     GLEXT_glActiveTextureARB(GL_TEXTURE0_ARB);
+
+    glsl_SetTextureDims(1, sizeof(fuzz) / sizeof(*fuzz), 1);
   }
 }
 
@@ -1616,9 +1628,9 @@ void gld_Precache(void)
 
   // e6y: some statistics
   {
-    char map[8];
+    char map[9];
 
-    strcpy(map, MAPNAME(gameepisode, gamemap));
+    snprintf(map, sizeof(map), "%s", dsda_MapLumpName(gameepisode, gamemap));
 
     lprintf(LO_DEBUG, "gld_Precache: %s done in %d ms\n", map, SDL_GetTicks() - tics);
   }
