@@ -143,7 +143,7 @@ void Heretic_F_TextWrite(void)
   int width;
 
   // e6y: wide-res
-  V_FillBorder(-1, 0);
+  V_ClearBorder();
 
   //
   // erase the entire screen to a tiled background
