@@ -108,7 +108,6 @@ cfg_def_t cfg_defs[] =
   MIGRATED_SETTING(dsda_config_movement_shorttics),
 
   SETTING_HEADING("Sound settings"),
-  MIGRATED_SETTING(dsda_config_snd_pcspeaker),
   MIGRATED_SETTING(dsda_config_pitched_sounds),
   MIGRATED_SETTING(dsda_config_full_sounds),
   MIGRATED_SETTING(dsda_config_snd_samplerate),
@@ -123,7 +122,14 @@ cfg_def_t cfg_defs[] =
   MIGRATED_SETTING(dsda_config_mus_fluidsynth_chorus),
   MIGRATED_SETTING(dsda_config_mus_fluidsynth_reverb),
   MIGRATED_SETTING(dsda_config_mus_fluidsynth_gain),
+  MIGRATED_SETTING(dsda_config_mus_fluidsynth_chorus_depth),
+  MIGRATED_SETTING(dsda_config_mus_fluidsynth_chorus_level),
+  MIGRATED_SETTING(dsda_config_mus_fluidsynth_reverb_damp),
+  MIGRATED_SETTING(dsda_config_mus_fluidsynth_reverb_level),
+  MIGRATED_SETTING(dsda_config_mus_fluidsynth_reverb_width),
+  MIGRATED_SETTING(dsda_config_mus_fluidsynth_reverb_room_size),
   MIGRATED_SETTING(dsda_config_mus_opl_gain),
+  MIGRATED_SETTING(dsda_config_mus_opl_opl3mode),
   MIGRATED_SETTING(dsda_config_mus_portmidi_reset_type),
   MIGRATED_SETTING(dsda_config_mus_portmidi_reset_delay),
   MIGRATED_SETTING(dsda_config_mus_portmidi_filter_sysex),
@@ -151,7 +157,7 @@ cfg_def_t cfg_defs[] =
   MIGRATED_SETTING(dsda_config_integer_scaling),
   MIGRATED_SETTING(dsda_config_render_aspect),
   MIGRATED_SETTING(dsda_config_render_doom_lightmaps),
-  MIGRATED_SETTING(dsda_config_fake_contrast),
+  MIGRATED_SETTING(dsda_config_fake_contrast_mode),
   MIGRATED_SETTING(dsda_config_render_stretch_hud),
   MIGRATED_SETTING(dsda_config_render_patches_scalex),
   MIGRATED_SETTING(dsda_config_render_patches_scaley),
@@ -164,6 +170,7 @@ cfg_def_t cfg_defs[] =
   MIGRATED_SETTING(dsda_config_gl_skymode),
   MIGRATED_SETTING(dsda_config_gl_health_bar),
   MIGRATED_SETTING(dsda_config_gl_usevbo),
+  MIGRATED_SETTING(dsda_config_gl_fade_mode),
 
   SETTING_HEADING("Mouse settings"),
   MIGRATED_SETTING(dsda_config_use_mouse),
