@@ -414,7 +414,6 @@ typedef struct mobj_s
 
 // External declarations (fomerly in p_local.h) -- killough 5/2/98
 
-#define GRAVITY         FRACUNIT
 #define MAXMOVE         (30*FRACUNIT)
 
 #define ONFLOORZ        INT_MIN
@@ -440,6 +439,7 @@ typedef struct mobj_s
 extern int iquehead;
 extern int iquetail;
 
+int P_MobjSpawnHealth(const mobj_t* mobj);
 mobj_t* P_SubstNullMobj (mobj_t* th);
 void    P_RespawnSpecials(void);
 mobj_t  *P_SpawnMobj(fixed_t x, fixed_t y, fixed_t z, mobjtype_t type);
@@ -456,6 +456,8 @@ void    P_SpawnPlayer(int n, const mapthing_t *mthing);
 dboolean P_CheckMissileSpawn(mobj_t*);  // killough 8/2/98
 void    P_ExplodeMissile(mobj_t*);    // killough
 
+void P_RemoveMonsters(void);
+
 // heretic
 
 // --- mobj.flags2 ---
