@@ -265,6 +265,17 @@ static void P_RunThinkers (void)
   T_MAPMusic();
 }
 
+void P_CleanThinkers (void)
+{
+  for (currentthinker = thinkercap.next;
+       currentthinker != &thinkercap;
+       currentthinker = currentthinker->next)
+  {
+    if (currentthinker->function == P_RemoveThinkerDelayed)
+      currentthinker->function(currentthinker);
+  }
+}
+
 static void P_FrozenTicker (void)
 {
   int i;
