@@ -46,6 +46,7 @@
 #include "dsda/build.h"
 #include "dsda/configuration.h"
 #include "dsda/pause.h"
+#include "dsda/scroll.h"
 #include "dsda/settings.h"
 
 #include "hexen/a_action.h"
@@ -57,7 +58,6 @@ typedef enum
 {
   INTERP_SectorFloor,
   INTERP_SectorCeiling,
-  INTERP_Vertex,
   INTERP_WallPanning,
   INTERP_FloorPanning,
   INTERP_CeilingPanning
@@ -235,10 +235,6 @@ static void R_CopyInterpToOld (int i)
   case INTERP_SectorCeiling:
     oldipos[i][0] = ((sector_t*)curipos[i].address)->ceilingheight;
     break;
-  case INTERP_Vertex:
-    oldipos[i][0] = ((vertex_t*)curipos[i].address)->x;
-    oldipos[i][1] = ((vertex_t*)curipos[i].address)->y;
-    break;
   case INTERP_WallPanning:
     oldipos[i][0] = ((side_t*)curipos[i].address)->rowoffset;
     oldipos[i][1] = ((side_t*)curipos[i].address)->textureoffset;
@@ -264,10 +260,6 @@ static void R_CopyBakToInterp (int i)
   case INTERP_SectorCeiling:
     ((sector_t*)curipos[i].address)->ceilingheight = bakipos[i][0];
     break;
-  case INTERP_Vertex:
-    ((vertex_t*)curipos[i].address)->x = bakipos[i][0];
-    ((vertex_t*)curipos[i].address)->y = bakipos[i][1];
-    break;
   case INTERP_WallPanning:
     ((side_t*)curipos[i].address)->rowoffset = bakipos[i][0];
     ((side_t*)curipos[i].address)->textureoffset = bakipos[i][1];
@@ -297,10 +289,6 @@ static void R_DoAnInterpolation (int i, fixed_t smoothratio)
   case INTERP_SectorCeiling:
     adr1 = &((sector_t*)curipos[i].address)->ceilingheight;
     break;
-  case INTERP_Vertex:
-    adr1 = &((vertex_t*)curipos[i].address)->x;
-////    adr2 = &((vertex_t*)curipos[i].Address)->y;
-    break;
   case INTERP_WallPanning:
     adr1 = &((side_t*)curipos[i].address)->rowoffset;
     adr2 = &((side_t*)curipos[i].address)->textureoffset;
@@ -577,24 +565,22 @@ static void R_InterpolationGetData(thinker_t *th,
     *posptr2 = ((elevator_t *)th)->sector;
   }
   else
-  if (th->function == T_Scroll)
+  if (th->function == dsda_UpdateSideScroller || th->function == dsda_UpdateControlSideScroller)
   {
-    switch (((scroll_t *)th)->type)
-    {
-      case sc_side:
-        *type1 = INTERP_WallPanning;
-        *posptr1 = sides + ((scroll_t *)th)->affectee;
-        break;
-      case sc_floor:
-        *type1 = INTERP_FloorPanning;
-        *posptr1 = sectors + ((scroll_t *)th)->affectee;
-        break;
-      case sc_ceiling:
-        *type1 = INTERP_CeilingPanning;
-        *posptr1 = sectors + ((scroll_t *)th)->affectee;
-        break;
-      default: ;
-    }
+    *type1 = INTERP_WallPanning;
+    *posptr1 = sides + ((scroll_t *)th)->affectee;
+  }
+  else
+  if (th->function == dsda_UpdateFloorScroller || th->function == dsda_UpdateControlFloorScroller)
+  {
+    *type1 = INTERP_FloorPanning;
+    *posptr1 = sectors + ((scroll_t *)th)->affectee;
+  }
+  else
+  if (th->function == dsda_UpdateCeilingScroller || th->function == dsda_UpdateControlCeilingScroller)
+  {
+    *type1 = INTERP_CeilingPanning;
+    *posptr1 = sectors + ((scroll_t *)th)->affectee;
   }
 }
 
