@@ -85,6 +85,8 @@ typedef struct
 
   dboolean active;
   dboolean ambient;
+  float attenuation;
+  float volume_factor;
   dboolean loop;
   int loop_timeout;
   sfx_class_t sfx_class;
@@ -284,6 +286,22 @@ void S_Start(void)
   }
 }
 
+static float adjust_attenuation;
+static float adjust_volume;
+
+void S_AdjustAttenuation(float attenuation) {
+  adjust_attenuation = attenuation;
+}
+
+void S_AdjustVolume(float volume) {
+  adjust_volume = volume;
+}
+
+void S_ResetAdjustments(void) {
+  adjust_attenuation = 0;
+  adjust_volume = 0;
+}
+
 void S_StartSoundAtVolume(void *origin_p, int sfx_id, int volume, int loop_timeout)
 {
   int cnum;
@@ -308,6 +326,8 @@ void S_StartSoundAtVolume(void *origin_p, int sfx_id, int volume, int loop_timeo
     params.sfx_class = sfx_class_none;
 
   params.ambient = false;
+  params.attenuation = adjust_attenuation;
+  params.volume_factor = adjust_volume;
   params.loop = loop_timeout > 0;
   params.loop_timeout = loop_timeout;
 
@@ -382,6 +402,8 @@ void S_StartSoundAtVolume(void *origin_p, int sfx_id, int volume, int loop_timeo
       channels[cnum].pitch = params.pitch;
       channels[cnum].priority = params.priority;
       channels[cnum].ambient = params.ambient;
+      channels[cnum].attenuation = params.attenuation;
+      channels[cnum].volume_factor = params.volume_factor;
       channels[cnum].loop = params.loop;
       channels[cnum].loop_timeout = params.loop_timeout;
       channels[cnum].active = true;
@@ -413,11 +435,24 @@ void S_StartMobjSound(mobj_t *mobj, int sfx_id)
   S_StartSound(mobj, sfx_id);
 }
 
+void S_LoopMobjSound(mobj_t *mobj, int sfx_id, int timeout)
+{
+  if (mobj && mobj->subsector && mobj->subsector->sector->flags & SECF_SILENT)
+    return;
+
+  S_LoopSound(mobj, sfx_id, timeout);
+}
+
 void S_StartVoidSound(int sfx_id)
 {
   S_StartSound(NULL, sfx_id);
 }
 
+void S_LoopVoidSound(int sfx_id, int timeout)
+{
+  S_LoopSound(NULL, sfx_id, timeout);
+}
+
 void S_StartLineSound(line_t *line, degenmobj_t *soundorg, int sfx_id)
 {
   if (line && line->frontsector && line->frontsector->flags & SECF_SILENT)
@@ -593,6 +628,20 @@ void S_StartMusic(int m_id)
   S_ChangeMusic(m_id, false);
 }
 
+dboolean S_ChangeMusicByName(const char *name, dboolean looping)
+{
+  int lump = W_CheckNumForName(name);
+
+  if (lump == LUMP_NOT_FOUND)
+  {
+    S_StopMusic();
+    return false;
+  }
+
+  S_ChangeMusInfoMusic(lump, looping);
+  return true;
+}
+
 void S_ChangeMusic(int musicnum, int looping)
 {
   musicinfo_t *music;
@@ -764,6 +813,8 @@ int S_AdjustSoundParams(mobj_t *listener, mobj_t *source, channel_t *channel, sf
   if (channel)
   {
     params->ambient = channel->ambient;
+    params->attenuation = channel->attenuation;
+    params->volume_factor = channel->volume_factor;
     params->loop = channel->loop;
     params->loop_timeout = channel->loop_timeout;
   }
@@ -784,6 +835,9 @@ int S_AdjustSoundParams(mobj_t *listener, mobj_t *source, channel_t *channel, sf
   approx_dist = P_AproxDistance(adx, ady);
   approx_dist >>= FRACBITS;
 
+  if (params->attenuation)
+    approx_dist *= params->attenuation;
+
   if (approx_dist >= max_snd_dist)
     return 0;
 
@@ -814,6 +868,11 @@ int S_AdjustSoundParams(mobj_t *listener, mobj_t *source, channel_t *channel, sf
   else
   {
     params->volume = (soundCurve[approx_dist] * sfx_volume * 8) >> 7;
+    if (params->volume_factor) {
+      params->volume *= params->volume_factor;
+      if (params->volume > 119)
+        params->volume = 119;
+    }
   }
 
   if (channel)
@@ -1092,6 +1151,8 @@ static void Raven_S_StartSoundAtVolume(void *_origin, int sound_id, int volume,
   sfx = &S_sfx[sound_id];
 
   params.ambient = heretic && sound_id >= heretic_sfx_wind;
+  params.attenuation = 0;
+  params.volume_factor = 0;
   params.loop = loop_timeout > 0;
   params.loop_timeout = loop_timeout;
 
@@ -1151,6 +1212,8 @@ static void Raven_S_StartSoundAtVolume(void *_origin, int sound_id, int volume,
   channels[cnum].priority = params.priority;
   channels[cnum].volume = volume; // original volume, not attenuated volume
   channels[cnum].ambient = params.ambient;
+  channels[cnum].attenuation = params.attenuation;
+  channels[cnum].volume_factor = params.volume_factor;
   channels[cnum].loop = params.loop;
   channels[cnum].loop_timeout = params.loop_timeout;
   channels[cnum].active = true;
@@ -1186,6 +1249,8 @@ void S_StartAmbientSound(void *_origin, int sound_id, int volume)
   params.separation = 128;
   params.sfx_class = sfx_class_none;
   params.ambient = true;
+  params.attenuation = 0;
+  params.volume_factor = 0;
   params.loop = false;
   params.loop_timeout = 0;
 
@@ -1206,6 +1271,8 @@ void S_StartAmbientSound(void *_origin, int sound_id, int volume)
   channels[i].sfxinfo = sfx;
   channels[i].priority = params.priority;
   channels[i].ambient = params.ambient;
+  channels[i].attenuation = params.attenuation;
+  channels[i].volume_factor = params.volume_factor;
   channels[i].loop = params.loop;
   channels[i].loop_timeout = params.loop_timeout;
   channels[i].active = true;
