@@ -214,6 +214,7 @@ typedef void (*V_DrawBackground_f)(const char* flatname, int scrn);
 extern V_DrawBackground_f V_DrawBackground;
 
 // CPhipps - function to set the palette to palette number pal.
+void V_TouchPalette(void);
 void V_SetPalette(int pal);
 void V_SetPlayPal(int playpal_index);
 
@@ -262,7 +263,7 @@ void V_FreePlaypal(void);
 int V_GetPlaypalCount(void);
 
 // e6y: wide-res
-void V_FillBorder(int lump, byte color);
+void V_ClearBorder(void);
 
 void V_GetWideRect(int *x, int *y, int *w, int *h, enum patch_translation_e flags);
 
